@@ -52,29 +52,40 @@ from PyGnuTLS.library.constants import (
     GNUTLS_X509_FMT_PEM,
 )
 
-from PyGnuTLS.library.types import gnutls_pkcs7_signature_info_st, gnutls_x509_dn_t
+from PyGnuTLS.library.types import (
+    gnutls_aead_cipher_hd_t,
+    gnutls_cipher_hd_t,
+    gnutls_datum_t,
+    gnutls_dh_params_t,
+    gnutls_digest_algorithm_t,
+    gnutls_pkcs7_signature_info_st,
+    gnutls_pkcs7_t,
+    gnutls_privkey_t,
+    gnutls_pubkey_t,
+    gnutls_typed_vdata_st,
+    gnutls_x509_crl_t,
+    gnutls_x509_crt_t,
+    gnutls_x509_dn_t,
+    gnutls_x509_privkey_t,
+    gnutls_x509_trust_list_t,
+)
 
 from PyGnuTLS.library.functions import (
     gnutls_aead_cipher_decrypt,
     gnutls_aead_cipher_deinit,
     gnutls_aead_cipher_encrypt,
-    gnutls_aead_cipher_hd_t,
     gnutls_aead_cipher_init,
     gnutls_cipher_add_auth,
     gnutls_cipher_decrypt2,
     gnutls_cipher_deinit,
     gnutls_cipher_encrypt2,
     gnutls_cipher_get_block_size,
-    gnutls_cipher_hd_t,
     gnutls_cipher_init,
     gnutls_cipher_set_iv,
     gnutls_cipher_tag,
-    gnutls_datum_t,
     gnutls_dh_params_deinit,
     gnutls_dh_params_generate2,
     gnutls_dh_params_init,
-    gnutls_dh_params_t,
-    gnutls_digest_algorithm_t,
     gnutls_hex_encode2,
     gnutls_pkcs7_deinit,
     gnutls_pkcs7_export,
@@ -84,7 +95,6 @@ from PyGnuTLS.library.functions import (
     gnutls_pkcs7_init,
     gnutls_pkcs7_sign,
     gnutls_pkcs7_signature_info_deinit,
-    gnutls_pkcs7_t,
     gnutls_pkcs7_verify,
     gnutls_pkcs7_verify_direct,
     gnutls_privkey_decrypt_data,
@@ -99,7 +109,6 @@ from PyGnuTLS.library.functions import (
     gnutls_privkey_init,
     gnutls_privkey_sign_data,
     gnutls_privkey_sign_hash,
-    gnutls_privkey_t,
     gnutls_pubkey_deinit,
     gnutls_pubkey_encrypt_data,
     gnutls_pubkey_export_dsa_raw,
@@ -112,10 +121,8 @@ from PyGnuTLS.library.functions import (
     gnutls_pubkey_import_url,
     gnutls_pubkey_import_x509,
     gnutls_pubkey_init,
-    gnutls_pubkey_t,
     gnutls_pubkey_verify_data2,
     gnutls_pubkey_verify_hash2,
-    gnutls_typed_vdata_st,
     gnutls_x509_crl_deinit,
     gnutls_x509_crl_export,
     gnutls_x509_crl_get_crt_count,
@@ -123,7 +130,6 @@ from PyGnuTLS.library.functions import (
     gnutls_x509_crl_get_version,
     gnutls_x509_crl_import,
     gnutls_x509_crl_init,
-    gnutls_x509_crl_t,
     gnutls_x509_crt_check_hostname,
     gnutls_x509_crt_check_issuer,
     gnutls_x509_crt_check_revocation,
@@ -138,7 +144,6 @@ from PyGnuTLS.library.functions import (
     gnutls_x509_crt_get_version,
     gnutls_x509_crt_import,
     gnutls_x509_crt_init,
-    gnutls_x509_crt_t,
     gnutls_x509_dn_deinit,
     gnutls_x509_dn_get_str2,
     gnutls_x509_dn_import,
@@ -147,12 +152,10 @@ from PyGnuTLS.library.functions import (
     gnutls_x509_privkey_export,
     gnutls_x509_privkey_import,
     gnutls_x509_privkey_init,
-    gnutls_x509_privkey_t,
     gnutls_x509_trust_list_add_cas,
     gnutls_x509_trust_list_add_trust_mem,
     gnutls_x509_trust_list_deinit,
     gnutls_x509_trust_list_init,
-    gnutls_x509_trust_list_t,
 )
 
 
@@ -242,10 +245,10 @@ class X509TrustList(CWrapper):
     def __del__(self):
         self.__deinit(self._c_object, 0)
 
-    def add_ca(self, cert: "X509Certificate", flags: int = 0):
+    def add_ca(self, cert: "X509Certificate", flags: int = 0) -> None:
         gnutls_x509_trust_list_add_cas(self._c_object, byref(cert._c_object), 1, flags)
 
-    def add_certificate(self, cert: "X509Certificate", flags: int = 0):
+    def add_certificate(self, cert: "X509Certificate", flags: int = 0) -> None:
 
         # mrrrggg, we have to export the certificate to a blob
         buf = cert.export()
@@ -327,10 +330,10 @@ class Pkcs7(CWrapper):
 
     def sign(
         self,
-        cert,
+        cert: "X509Certificate",
         privkey: Union["X509PrivateKey", "PrivateKey"],
         buf: bytes,
-        hash_algo: int = None,
+        hash_algo: Optional[int] = None,
         flags: int = 0,
     ) -> None:
 
@@ -371,7 +374,7 @@ class Pkcs7(CWrapper):
 
     def verify_direct(
         self, cert: "X509Certificate", buf: bytes, idx: int = -1, flags: int = 0
-    ):
+    ) -> None:
         data = gnutls_datum_t(buf)
 
         # by default, check all signatures in context
@@ -484,7 +487,7 @@ class PrivateKey(object):
         return pk.upcast(algo, pk)
 
     @classmethod
-    def pk_algorithm_to_keytype(cls, algo: int):
+    def pk_algorithm_to_keytype(cls, algo: int) -> int:
         if algo in [GNUTLS_PK_RSA, GNUTLS_PK_RSA_PSS]:
             return PrivateKey.KEY_TYPE_RSA
         if algo in [GNUTLS_PK_DSA]:
@@ -630,7 +633,9 @@ class PublicKey(object):
         return pubkey
 
     @staticmethod
-    def import_uri(uri: str, flags: int = 0, srk_password: str = None):
+    def import_uri(
+        uri: str, flags: int = 0, srk_password: Optional[str] = None
+    ) -> Union["PublicKey", "RSAPublicKey", "DSAPublicKey"]:
         pubkey = PublicKey()
         if not srk_password:
             gnutls_pubkey_import_url(pubkey._c_object, uri, flags)
@@ -639,7 +644,9 @@ class PublicKey(object):
         algo = gnutls_pubkey_get_pk_algorithm(pubkey._c_object, None)
         return pubkey.upcast(algo, pubkey)
 
-    def verify_data2(self, sign_algo: int, flags: int, buf: bytes, signature):
+    def verify_data2(
+        self, sign_algo: int, flags: int, buf: bytes, signature: bytes
+    ) -> None:
         gnutls_pubkey_verify_data2(
             self._c_object,
             sign_algo,
@@ -650,7 +657,7 @@ class PublicKey(object):
 
     def verify_hash2(
         self, sign_algo: int, flags: int, hashbuf: bytes, signature: bytes
-    ):
+    ) -> None:
         gnutls_pubkey_verify_hash2(
             self._c_object,
             sign_algo,
@@ -691,7 +698,7 @@ class DSAPublicKey(PublicKey):
         super(DSAPublicKey, self).__init__(pubkey=pubkey)
 
     @staticmethod
-    def import_dsa_raw(p: bytes, q: bytes, g: bytes, y: bytes):
+    def import_dsa_raw(p: bytes, q: bytes, g: bytes, y: bytes) -> "DSAPublicKey":
         pubkey = PublicKey()
         gnutls_pubkey_import_dsa_raw(
             pubkey._c_object,
@@ -790,7 +797,7 @@ class X509Certificate(CWrapper):
         gnutls_x509_crt_get_serial(
             self._c_object, cast(byref(serial), c_void_p), byref(size)
         )
-        return serial.value.hex().lstrip("0")
+        return serial.value.hex()
 
     @property
     def activation_time(self) -> int:
@@ -932,12 +939,14 @@ class X509CRL(CWrapper):
             gnutls_x509_crt_check_revocation(cert._c_object, byref(self._c_object), 1)
         )
 
-    def check_revocation(self, cert: X509Certificate, cert_name: str = "certificate"):
+    def check_revocation(
+        self, cert: X509Certificate, cert_name: str = "certificate"
+    ) -> None:
         """Raise CertificateRevokedError if the given certificate is revoked"""
         if self.is_revoked(cert):
             raise CertificateRevokedError("%s was revoked" % cert_name)
 
-    def export(self, format: int = GNUTLS_X509_FMT_PEM):
+    def export(self, format: int = GNUTLS_X509_FMT_PEM) -> bytes:
         size = c_size_t(4096)
         pemdata = create_string_buffer(size.value)
         try:
@@ -984,10 +993,10 @@ class Cipher(CWrapper):
         self.algorithm = algo
         self.deinit = gnutls_cipher_deinit
 
-    def set_iv(self, iv: bytes):
+    def set_iv(self, iv: bytes) -> None:
         gnutls_cipher_set_iv(self._c_object, c_char_p(iv), c_size_t(len(iv)))
 
-    def add_auth(self, auth: bytes):
+    def add_auth(self, auth: bytes) -> None:
         gnutls_cipher_add_auth(self._c_object, c_char_p(auth), c_size_t(len(auth)))
 
     def decrypt(self, cipher_text: bytes) -> bytes:
@@ -1013,7 +1022,7 @@ class Cipher(CWrapper):
         )
         return ct.value
 
-    def cipher_tag(self, tag_size: int):
+    def cipher_tag(self, tag_size: int) -> bytes:
         assert tag_size > 0
         tag = create_string_buffer(tag_size)
         gnutls_cipher_tag(self._c_object, tag, c_size_t(tag_size))
